@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.7.6.  */
+/* A Bison parser, made by GNU Bison 3.8.1.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30706
+#define YYBISON 30801
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.7.6"
+#define YYBISON_VERSION "3.8.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -72,7 +72,7 @@
 #define yynerrs         constexpYYnerrs
 
 /* First part of user prologue.  */
-#line 16 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 16 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
 
 
 #include "cppvalue.h"
@@ -91,7 +91,7 @@ int constexpYYerror(yyscan_t yyscanner, const char *s)
 }
 
 
-#line 95 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 95 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -325,12 +325,18 @@ typedef int yy_state_fast_t;
 # define YY_USE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
-# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                            \
+#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
+# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
+    _Pragma ("GCC diagnostic push")                                     \
+    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
+# else
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
     _Pragma ("GCC diagnostic push")                                     \
     _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
     _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
+# endif
 # define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
     _Pragma ("GCC diagnostic pop")
 #else
@@ -547,7 +553,7 @@ static const yytype_int8 yytranslate[] =
 };
 
 #if YYDEBUG
-  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
+/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
        0,    73,    73,    80,    82,    91,    93,    99,   101,   107,
@@ -592,18 +598,6 @@ yysymbol_name (yysymbol_kind_t yysymbol)
 }
 #endif
 
-#ifdef YYPRINT
-/* YYTOKNUM[NUM] -- (External) token number corresponding to the
-   (internal) symbol number NUM (which must be that of a token).  */
-static const yytype_int16 yytoknum[] =
-{
-       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
-     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
-     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
-     285,   286,   287
-};
-#endif
-
 #define YYPACT_NINF (-30)
 
 #define yypact_value_is_default(Yyn) \
@@ -614,8 +608,8 @@ static const yytype_int16 yytoknum[] =
 #define yytable_value_is_error(Yyn) \
   0
 
-  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
-     STATE-NUM.  */
+/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
+   STATE-NUM.  */
 static const yytype_int8 yypact[] =
 {
      -13,   -13,   -13,   -13,   -13,   -13,   -30,   -30,   -30,   -30,
@@ -628,9 +622,9 @@ static const yytype_int8 yypact[] =
      -30,   -30,   -13,    39
 };
 
-  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
-     Performed when YYTABLE does not specify something else to do.  Zero
-     means the default is an error.  */
+/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
+   Performed when YYTABLE does not specify something else to do.  Zero
+   means the default is an error.  */
 static const yytype_int8 yydefact[] =
 {
        0,     0,     0,     0,     0,     0,    40,    41,    42,    43,
@@ -643,23 +637,23 @@ static const yytype_int8 yydefact[] =
       31,    32,     0,     4
 };
 
-  /* YYPGOTO[NTERM-NUM].  */
+/* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
      -30,   -30,    49,   -29,    21,    23,    24,    26,    27,     2,
      -17,     0,     5,    -1,   -30,   -30
 };
 
-  /* YYDEFGOTO[NTERM-NUM].  */
+/* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
        0,    12,    13,    14,    15,    16,    17,    18,    19,    20,
       21,    22,    23,    24,    25,    26
 };
 
-  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
-     positive, shift that token.  If negative, reduce the rule whose
-     number is the opposite.  If YYTABLE_NINF, syntax error.  */
+/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
+   positive, shift that token.  If negative, reduce the rule whose
+   number is the opposite.  If YYTABLE_NINF, syntax error.  */
 static const yytype_int8 yytable[] =
 {
       27,    28,    29,    30,    53,     1,     2,    33,    36,    34,
@@ -682,8 +676,8 @@ static const yytype_int8 yycheck[] =
       36,    -1,    -1,    37,    -1,    38
 };
 
-  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
-     symbol of state STATE-NUM.  */
+/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
+   state STATE-NUM.  */
 static const yytype_int8 yystos[] =
 {
        0,    18,    19,    23,    24,    25,    27,    28,    29,    30,
@@ -696,7 +690,7 @@ static const yytype_int8 yystos[] =
       46,    46,     4,    36
 };
 
-  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
+/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr1[] =
 {
        0,    33,    34,    35,    35,    36,    36,    37,    37,    38,
@@ -706,7 +700,7 @@ static const yytype_int8 yyr1[] =
       48,    48,    48,    48,    48,    48
 };
 
-  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
+/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr2[] =
 {
        0,     2,     1,     1,     5,     1,     3,     1,     3,     1,
@@ -725,6 +719,7 @@ enum { YYENOMEM = -2 };
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
 #define YYERROR         goto yyerrorlab
+#define YYNOMEM         goto yyexhaustedlab
 
 
 #define YYRECOVERING()  (!!yyerrstatus)
@@ -765,10 +760,7 @@ do {                                            \
     YYFPRINTF Args;                             \
 } while (0)
 
-/* This macro is provided for backward compatibility. */
-# ifndef YY_LOCATION_PRINT
-#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
-# endif
+
 
 
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
@@ -796,10 +788,6 @@ yy_symbol_value_print (FILE *yyo,
   YY_USE (yyscanner);
   if (!yyvaluep)
     return;
-# ifdef YYPRINT
-  if (yykind < YYNTOKENS)
-    YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
-# endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   YY_USE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
@@ -991,6 +979,7 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yychar = YYEMPTY; /* Cause a token to be read.  */
+
   goto yysetstate;
 
 
@@ -1016,7 +1005,7 @@ yysetstate:
 
   if (yyss + yystacksize - 1 <= yyssp)
 #if !defined yyoverflow && !defined YYSTACK_RELOCATE
-    goto yyexhaustedlab;
+    YYNOMEM;
 #else
     {
       /* Get the current used size of the three stacks, in elements.  */
@@ -1044,7 +1033,7 @@ yysetstate:
 # else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
-        goto yyexhaustedlab;
+        YYNOMEM;
       yystacksize *= 2;
       if (YYMAXDEPTH < yystacksize)
         yystacksize = YYMAXDEPTH;
@@ -1055,7 +1044,7 @@ yysetstate:
           YY_CAST (union yyalloc *,
                    YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
         if (! yyptr)
-          goto yyexhaustedlab;
+          YYNOMEM;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
@@ -1077,6 +1066,7 @@ yysetstate:
     }
 #endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
+
   if (yystate == YYFINAL)
     YYACCEPT;
 
@@ -1189,189 +1179,189 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* start: constant_expression  */
-#line 74 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 74 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
        {
          struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
          yyextra->resultValue = yyvsp[0]; return 0;
        }
-#line 1198 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1188 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 3: /* constant_expression: logical_or_expression  */
-#line 81 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 81 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                      { yyval = yyvsp[0]; }
-#line 1204 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1194 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 4: /* constant_expression: logical_or_expression TOK_QUESTIONMARK logical_or_expression TOK_COLON logical_or_expression  */
-#line 85 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 85 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                      {
 		       bool c = (yyvsp[-4].isInt() ? ((long)yyvsp[-4] != 0) : ((double)yyvsp[-4] != 0.0));
 		       yyval = c ? yyvsp[-2] : yyvsp[0];
 	             }
-#line 1213 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1203 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 5: /* logical_or_expression: logical_and_expression  */
-#line 92 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 92 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                        { yyval = yyvsp[0]; }
-#line 1219 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1209 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 6: /* logical_or_expression: logical_or_expression TOK_OR logical_and_expression  */
-#line 94 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 94 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                        {
 			 yyval = CPPValue( (long)((long)yyvsp[-2] || (long)yyvsp[0]) );
 		       }
-#line 1227 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1217 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 7: /* logical_and_expression: inclusive_or_expression  */
-#line 100 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 100 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                         { yyval = yyvsp[0]; }
-#line 1233 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1223 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 8: /* logical_and_expression: logical_and_expression TOK_AND inclusive_or_expression  */
-#line 102 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 102 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                         {
 			  yyval = CPPValue( (long)((long)yyvsp[-2] && (long)yyvsp[0]) );
 			}
-#line 1241 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1231 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 9: /* inclusive_or_expression: exclusive_or_expression  */
-#line 108 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 108 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                          { yyval = yyvsp[0]; }
-#line 1247 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1237 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 10: /* inclusive_or_expression: inclusive_or_expression TOK_BITWISEOR exclusive_or_expression  */
-#line 111 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 111 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                          {
 			   yyval = CPPValue( (long)yyvsp[-2] | (long)yyvsp[0] );
 			 }
-#line 1255 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1245 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 11: /* exclusive_or_expression: and_expression  */
-#line 117 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 117 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                          { yyval = yyvsp[0]; }
-#line 1261 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1251 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 12: /* exclusive_or_expression: exclusive_or_expression TOK_BITWISEXOR and_expression  */
-#line 119 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 119 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                          {
 			   yyval = CPPValue( (long)yyvsp[-2] ^ (long)yyvsp[0] );
 			 }
-#line 1269 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1259 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 13: /* and_expression: equality_expression  */
-#line 125 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 125 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                 { yyval = yyvsp[0]; }
-#line 1275 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1265 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 14: /* and_expression: and_expression TOK_AMPERSAND equality_expression  */
-#line 127 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 127 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                 {
 		  yyval = CPPValue( (long)yyvsp[-2] & (long)yyvsp[0] );
 		}
-#line 1283 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1273 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 15: /* equality_expression: relational_expression  */
-#line 133 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 133 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                      { yyval = yyvsp[0]; }
-#line 1289 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1279 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 16: /* equality_expression: equality_expression TOK_EQUAL relational_expression  */
-#line 135 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 135 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                      {
 		       yyval = CPPValue( (long)((double)yyvsp[-2] == (double)yyvsp[0]) );
 	             }
-#line 1297 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1287 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 17: /* equality_expression: equality_expression TOK_NOTEQUAL relational_expression  */
-#line 139 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 139 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                      {
                        yyval = CPPValue( (long)((double)yyvsp[-2] != (double)yyvsp[0]) );
 		     }
-#line 1305 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1295 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 18: /* relational_expression: shift_expression  */
-#line 145 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 145 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                        { yyval = yyvsp[0]; }
-#line 1311 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1301 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 19: /* relational_expression: relational_expression TOK_LESSTHAN shift_expression  */
-#line 147 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 147 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                        {
 			 yyval = CPPValue( (long)((double)yyvsp[-2] < (double)yyvsp[0]) );
 		       }
-#line 1319 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1309 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 20: /* relational_expression: relational_expression TOK_GREATERTHAN shift_expression  */
-#line 151 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 151 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                        {
                          yyval = CPPValue( (long)((double)yyvsp[-2] > (double)yyvsp[0]) );
 		       }
-#line 1327 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1317 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 21: /* relational_expression: relational_expression TOK_LESSTHANOREQUALTO shift_expression  */
-#line 156 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 156 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                        {
 		         yyval = CPPValue( (long)((double)yyvsp[-2] <= (double)yyvsp[0]) );
 		       }
-#line 1335 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1325 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 22: /* relational_expression: relational_expression TOK_GREATERTHANOREQUALTO shift_expression  */
-#line 161 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 161 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                        {
 			 yyval = CPPValue( (long)((double)yyvsp[-2] >= (double)yyvsp[0]) );
 		       }
-#line 1343 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1333 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 23: /* shift_expression: additive_expression  */
-#line 167 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 167 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                   { yyval = yyvsp[0]; }
-#line 1349 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1339 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 24: /* shift_expression: shift_expression TOK_SHIFTLEFT additive_expression  */
-#line 169 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 169 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                   {
 		    yyval = CPPValue( (long)yyvsp[-2] << (long)yyvsp[0] );
 		  }
-#line 1357 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1347 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 25: /* shift_expression: shift_expression TOK_SHIFTRIGHT additive_expression  */
-#line 173 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 173 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                   {
 		    yyval = CPPValue( (long)yyvsp[-2] >> (long)yyvsp[0] );
 		  }
-#line 1365 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1355 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 26: /* additive_expression: multiplicative_expression  */
-#line 179 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 179 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                      { yyval = yyvsp[0]; }
-#line 1371 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1361 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 27: /* additive_expression: additive_expression TOK_PLUS multiplicative_expression  */
-#line 181 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 181 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                      {
 		       if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
 		       {
@@ -1382,11 +1372,11 @@ yyreduce:
 		         yyval = CPPValue( (long)yyvsp[-2] + (long)yyvsp[0] );
 		       }
 		     }
-#line 1386 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1376 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 28: /* additive_expression: additive_expression TOK_MINUS multiplicative_expression  */
-#line 192 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 192 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                      {
 		       if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
 		       {
@@ -1397,17 +1387,17 @@ yyreduce:
 		         yyval = CPPValue( (long)yyvsp[-2] - (long)yyvsp[0] );
 		       }
 		     }
-#line 1401 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1391 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 29: /* multiplicative_expression: unary_expression  */
-#line 205 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 205 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                            { yyval = yyvsp[0]; }
-#line 1407 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1397 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 30: /* multiplicative_expression: multiplicative_expression TOK_STAR unary_expression  */
-#line 207 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 207 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                            {
 			     if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
 			     {
@@ -1418,11 +1408,11 @@ yyreduce:
 			       yyval = CPPValue( (long)yyvsp[-2] * (long)yyvsp[0] );
 			     }
 			   }
-#line 1422 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1412 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 31: /* multiplicative_expression: multiplicative_expression TOK_DIVIDE unary_expression  */
-#line 218 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 218 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                            {
 			     if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
 			     {
@@ -1435,126 +1425,126 @@ yyreduce:
 			       yyval = CPPValue( (long)yyvsp[-2] / value );
 			     }
 			   }
-#line 1439 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1429 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 32: /* multiplicative_expression: multiplicative_expression TOK_MOD unary_expression  */
-#line 231 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 231 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                            {
 			     long value = yyvsp[0];
 			     if (value==0) value=1;
 			     yyval = CPPValue( (long)yyvsp[-2] % value );
 			   }
-#line 1449 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1439 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 33: /* unary_expression: primary_expression  */
-#line 239 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 239 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                   { yyval = yyvsp[0]; }
-#line 1455 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1445 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 34: /* unary_expression: TOK_PLUS unary_expression  */
-#line 241 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 241 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                   { yyval = yyvsp[-1]; }
-#line 1461 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1451 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 35: /* unary_expression: TOK_MINUS unary_expression  */
-#line 243 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 243 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                   {
 		    if (yyvsp[0].isInt())
                       yyval = CPPValue(-(long)yyvsp[0]);
                     else
 		      yyval = CPPValue(-(double)yyvsp[0]);
 		  }
-#line 1472 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1462 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 36: /* unary_expression: TOK_TILDE unary_expression  */
-#line 250 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 250 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                   {
 		    yyval = CPPValue(~(long)yyvsp[0]);
 		  }
-#line 1480 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1470 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 37: /* unary_expression: TOK_NOT unary_expression  */
-#line 254 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 254 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                   {
 		    yyval = CPPValue((long)!(long)yyvsp[0]);
 		  }
-#line 1488 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1478 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 38: /* primary_expression: constant  */
-#line 260 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 260 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                     { yyval = yyvsp[0]; }
-#line 1494 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1484 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 39: /* primary_expression: TOK_LPAREN constant_expression TOK_RPAREN  */
-#line 262 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 262 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
                     { yyval = yyvsp[-1]; }
-#line 1500 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1490 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 40: /* constant: TOK_OCTALINT  */
-#line 266 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 266 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = parseOctal(yyextra->strToken);
 	  }
-#line 1509 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1499 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 41: /* constant: TOK_DECIMALINT  */
-#line 271 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 271 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = parseDecimal(yyextra->strToken);
 	  }
-#line 1518 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1508 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 42: /* constant: TOK_HEXADECIMALINT  */
-#line 276 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 276 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = parseHexadecimal(yyextra->strToken);
 	  }
-#line 1527 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1517 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 43: /* constant: TOK_BINARYINT  */
-#line 281 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 281 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = parseBinary(yyextra->strToken);
 	  }
-#line 1536 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1526 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 44: /* constant: TOK_CHARACTER  */
-#line 286 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 286 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = parseCharacter(yyextra->strToken);
 	  }
-#line 1545 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1535 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
   case 45: /* constant: TOK_FLOAT  */
-#line 291 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 291 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
 	    yyval = parseFloat(yyextra->strToken);
 	  }
-#line 1554 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1544 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
     break;
 
 
-#line 1558 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/build/generated_src/ce_parse.cpp"
+#line 1548 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/ce_parse.cpp"
 
       default: break;
     }
@@ -1636,6 +1626,7 @@ yyerrorlab:
      label yyerrorlab therefore never appears in user code.  */
   if (0)
     YYERROR;
+  ++yynerrs;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1696,7 +1687,7 @@ yyerrlab1:
 `-------------------------------------*/
 yyacceptlab:
   yyresult = 0;
-  goto yyreturn;
+  goto yyreturnlab;
 
 
 /*-----------------------------------.
@@ -1704,24 +1695,22 @@ yyacceptlab:
 `-----------------------------------*/
 yyabortlab:
   yyresult = 1;
-  goto yyreturn;
+  goto yyreturnlab;
 
 
-#if !defined yyoverflow
-/*-------------------------------------------------.
-| yyexhaustedlab -- memory exhaustion comes here.  |
-`-------------------------------------------------*/
+/*-----------------------------------------------------------.
+| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
+`-----------------------------------------------------------*/
 yyexhaustedlab:
   yyerror (yyscanner, YY_("memory exhausted"));
   yyresult = 2;
-  goto yyreturn;
-#endif
+  goto yyreturnlab;
 
 
-/*-------------------------------------------------------.
-| yyreturn -- parsing is finished, clean up and return.  |
-`-------------------------------------------------------*/
-yyreturn:
+/*----------------------------------------------------------.
+| yyreturnlab -- parsing is finished, clean up and return.  |
+`----------------------------------------------------------*/
+yyreturnlab:
   if (yychar != YYEMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
@@ -1748,5 +1737,5 @@ yyreturn:
   return yyresult;
 }
 
-#line 297 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.i686/src/doxygen-1.9.2/src/constexp.y"
+#line 297 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/constexp.y"
 
