@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.7.6.  */
+/* A Bison parser, made by GNU Bison 3.8.1.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30706
+#define YYBISON 30801
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.7.6"
+#define YYBISON_VERSION "3.8.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -294,7 +294,7 @@ Msc MscParse(FILE *in)
 
 
 
-#line 298 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 298 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -554,12 +554,18 @@ typedef int yy_state_fast_t;
 # define YY_USE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
-# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                            \
+#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
+# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
+    _Pragma ("GCC diagnostic push")                                     \
+    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
+# else
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
     _Pragma ("GCC diagnostic push")                                     \
     _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
     _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
+# endif
 # define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
     _Pragma ("GCC diagnostic pop")
 #else
@@ -779,7 +785,7 @@ static const yytype_int8 yytranslate[] =
 };
 
 #if YYDEBUG
-  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
+/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
        0,   290,   290,   296,   303,   304,   309,   314,   314,   314,
@@ -834,20 +840,6 @@ yysymbol_name (yysymbol_kind_t yysymbol)
 }
 #endif
 
-#ifdef YYPRINT
-/* YYTOKNUM[NUM] -- (External) token number corresponding to the
-   (internal) symbol number NUM (which must be that of a token).  */
-static const yytype_int16 yytoknum[] =
-{
-       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
-     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
-     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
-     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
-     295,   296,   297,   298,   299,   300,   301,   302,   303,   304,
-     305,   306,   307,   308,   309,   310
-};
-#endif
-
 #define YYPACT_NINF (-36)
 
 #define yypact_value_is_default(Yyn) \
@@ -858,8 +850,8 @@ static const yytype_int16 yytoknum[] =
 #define yytable_value_is_error(Yyn) \
   0
 
-  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
-     STATE-NUM.  */
+/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
+   STATE-NUM.  */
 static const yytype_int8 yypact[] =
 {
       -6,    35,    48,    15,   -36,   -36,   -36,   -36,   -36,   -36,
@@ -875,9 +867,9 @@ static const yytype_int8 yypact[] =
      -36,   -36
 };
 
-  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
-     Performed when YYTABLE does not specify something else to do.  Zero
-     means the default is an error.  */
+/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
+   Performed when YYTABLE does not specify something else to do.  Zero
+   means the default is an error.  */
 static const yytype_int8 yydefact[] =
 {
        0,     0,     0,     0,     1,    68,    67,     7,     8,     9,
@@ -893,23 +885,23 @@ static const yytype_int8 yydefact[] =
       18,     2
 };
 
-  /* YYPGOTO[NTERM-NUM].  */
+/* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
      -36,   -36,   -36,    52,   -36,    54,    50,    24,   -35,   -36,
      -36,   -36,   -36,   -36,    41,    22,    21,   -36,    -3
 };
 
-  /* YYDEFGOTO[NTERM-NUM].  */
+/* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
        0,     2,    11,    12,    13,    14,    15,    29,    30,    31,
       77,    78,    79,    80,    54,    44,    45,    46,    32
 };
 
-  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
-     positive, shift that token.  If negative, reduce the rule whose
-     number is the opposite.  If YYTABLE_NINF, syntax error.  */
+/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
+   positive, shift that token.  If negative, reduce the rule whose
+   number is the opposite.  If YYTABLE_NINF, syntax error.  */
 static const yytype_int8 yytable[] =
 {
       16,     5,     6,     5,     6,    82,     1,    88,    19,   101,
@@ -944,8 +936,8 @@ static const yytype_int8 yycheck[] =
       30,    -1,    -1,    33,    -1,    -1,    36,    -1,    -1,    39
 };
 
-  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
-     symbol of state STATE-NUM.  */
+/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
+   state STATE-NUM.  */
 static const yytype_int8 yystos[] =
 {
        0,    12,    57,     8,     0,     3,     4,    45,    46,    47,
@@ -961,7 +953,7 @@ static const yytype_int8 yystos[] =
       11,     9
 };
 
-  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
+/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr1[] =
 {
        0,    56,    57,    57,    58,    58,    59,    60,    60,    60,
@@ -973,7 +965,7 @@ static const yytype_int8 yyr1[] =
       73,    73,    73,    73,    73,    73,    73,    74,    74
 };
 
-  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
+/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr2[] =
 {
        0,     2,     9,     7,     1,     3,     3,     1,     1,     1,
@@ -994,6 +986,7 @@ enum { YYENOMEM = -2 };
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
 #define YYERROR         goto yyerrorlab
+#define YYNOMEM         goto yyexhaustedlab
 
 
 #define YYRECOVERING()  (!!yyerrstatus)
@@ -1034,10 +1027,7 @@ do {                                            \
     YYFPRINTF Args;                             \
 } while (0)
 
-/* This macro is provided for backward compatibility. */
-# ifndef YY_LOCATION_PRINT
-#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
-# endif
+
 
 
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
@@ -1065,10 +1055,6 @@ yy_symbol_value_print (FILE *yyo,
   YY_USE (YYPARSE_PARAM);
   if (!yyvaluep)
     return;
-# ifdef YYPRINT
-  if (yykind < YYNTOKENS)
-    YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
-# endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   YY_USE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
@@ -1254,6 +1240,7 @@ yyparse (void *YYPARSE_PARAM)
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yychar = YYEMPTY; /* Cause a token to be read.  */
+
   goto yysetstate;
 
 
@@ -1279,7 +1266,7 @@ yysetstate:
 
   if (yyss + yystacksize - 1 <= yyssp)
 #if !defined yyoverflow && !defined YYSTACK_RELOCATE
-    goto yyexhaustedlab;
+    YYNOMEM;
 #else
     {
       /* Get the current used size of the three stacks, in elements.  */
@@ -1307,7 +1294,7 @@ yysetstate:
 # else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
-        goto yyexhaustedlab;
+        YYNOMEM;
       yystacksize *= 2;
       if (YYMAXDEPTH < yystacksize)
         yystacksize = YYMAXDEPTH;
@@ -1318,7 +1305,7 @@ yysetstate:
           YY_CAST (union yyalloc *,
                    YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
         if (! yyptr)
-          goto yyexhaustedlab;
+          YYNOMEM;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
@@ -1340,6 +1327,7 @@ yysetstate:
     }
 #endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
+
   if (yystate == YYFINAL)
     YYACCEPT;
 
@@ -1458,7 +1446,7 @@ yyreduce:
     *(Msc *)yyparse_result = (yyval.msc);
 
 }
-#line 1462 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1450 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 3: /* msc: TOK_MSC TOK_OCBRACKET entitylist TOK_SEMICOLON arclist TOK_SEMICOLON TOK_CCBRACKET  */
@@ -1468,7 +1456,7 @@ yyreduce:
     *(Msc *)yyparse_result = (yyval.msc);
 
 }
-#line 1472 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1460 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 5: /* optlist: optlist TOK_COMMA opt  */
@@ -1476,7 +1464,7 @@ yyreduce:
 {
     (yyval.opt) = MscLinkOpt((yyvsp[-2].opt), (yyvsp[0].opt));
 }
-#line 1480 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1468 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 6: /* opt: optval TOK_EQUAL string  */
@@ -1484,7 +1472,7 @@ yyreduce:
 {
     (yyval.opt) = MscAllocOpt((yyvsp[-2].optType), (yyvsp[0].string));
 }
-#line 1488 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1476 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 11: /* entitylist: entity  */
@@ -1492,7 +1480,7 @@ yyreduce:
 {
     (yyval.entitylist) = MscLinkEntity(NULL, (yyvsp[0].entity));   /* Create new list */
 }
-#line 1496 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1484 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 12: /* entitylist: entitylist TOK_COMMA entity  */
@@ -1500,7 +1488,7 @@ yyreduce:
 {
     (yyval.entitylist) = MscLinkEntity((yyvsp[-2].entitylist), (yyvsp[0].entity));     /* Add to existing list */
 }
-#line 1504 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1492 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 13: /* entity: string  */
@@ -1508,7 +1496,7 @@ yyreduce:
 {
     (yyval.entity) = MscAllocEntity((yyvsp[0].string));
 }
-#line 1512 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1500 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 14: /* entity: entity TOK_OSBRACKET attrlist TOK_CSBRACKET  */
@@ -1516,7 +1504,7 @@ yyreduce:
 {
     MscEntityLinkAttrib((yyvsp[-3].entity), (yyvsp[-1].attrib));
 }
-#line 1520 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1508 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 15: /* arclist: arc  */
@@ -1524,7 +1512,7 @@ yyreduce:
 {
     (yyval.arclist) = MscLinkArc(NULL, (yyvsp[0].arc));      /* Create new list */
 }
-#line 1528 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1516 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 16: /* arclist: arclist TOK_SEMICOLON arc  */
@@ -1532,7 +1520,7 @@ yyreduce:
 {
     (yyval.arclist) = MscLinkArc((yyvsp[-2].arclist), (yyvsp[0].arc));     /* Add to existing list */
 }
-#line 1536 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1524 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 17: /* arclist: arclist TOK_COMMA arc  */
@@ -1541,7 +1529,7 @@ yyreduce:
     /* Add a special 'parallel' arc */
     (yyval.arclist) = MscLinkArc(MscLinkArc((yyvsp[-2].arclist), MscAllocArc(NULL, NULL, MSC_ARC_PARALLEL, lex_getlinenum())), (yyvsp[0].arc));
 }
-#line 1545 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1533 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 18: /* arc: arcrel TOK_OSBRACKET attrlist TOK_CSBRACKET  */
@@ -1549,7 +1537,7 @@ yyreduce:
 {
     MscArcLinkAttrib((yyvsp[-3].arc), (yyvsp[-1].attrib));
 }
-#line 1553 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1541 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 20: /* arcrel: TOK_SPECIAL_ARC  */
@@ -1557,7 +1545,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc(NULL, NULL, (yyvsp[0].arctype), lex_getlinenum());
 }
-#line 1561 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1549 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 21: /* arcrel: string relation_box string  */
@@ -1565,7 +1553,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc((yyvsp[-2].string), (yyvsp[0].string), (yyvsp[-1].arctype), lex_getlinenum());
 }
-#line 1569 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1557 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 22: /* arcrel: string relation_bi string  */
@@ -1575,7 +1563,7 @@ yyreduce:
     MscArcLinkAttrib(arc, MscAllocAttrib(MSC_ATTR_BI_ARROWS, strdup_s("true")));
     (yyval.arc) = arc;
 }
-#line 1579 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1567 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 23: /* arcrel: string relation_to string  */
@@ -1583,7 +1571,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc((yyvsp[-2].string), (yyvsp[0].string), (yyvsp[-1].arctype), lex_getlinenum());
 }
-#line 1587 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1575 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 24: /* arcrel: string relation_line string  */
@@ -1593,7 +1581,7 @@ yyreduce:
     MscArcLinkAttrib(arc, MscAllocAttrib(MSC_ATTR_NO_ARROWS, strdup_s("true")));
     (yyval.arc) = arc;
 }
-#line 1597 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1585 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 25: /* arcrel: string relation_from string  */
@@ -1601,7 +1589,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc((yyvsp[0].string), (yyvsp[-2].string), (yyvsp[-1].arctype), lex_getlinenum());
 }
-#line 1605 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1593 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 26: /* arcrel: string relation_to TOK_ASTERISK  */
@@ -1609,7 +1597,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc((yyvsp[-2].string), strdup_s("*"), (yyvsp[-1].arctype), lex_getlinenum());
 }
-#line 1613 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1601 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 27: /* arcrel: TOK_ASTERISK relation_from string  */
@@ -1617,7 +1605,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc((yyvsp[0].string), strdup_s("*"), (yyvsp[-1].arctype), lex_getlinenum());
 }
-#line 1621 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1609 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 54: /* attrlist: attrlist TOK_COMMA attr  */
@@ -1625,7 +1613,7 @@ yyreduce:
 {
     (yyval.attrib) = MscLinkAttrib((yyvsp[-2].attrib), (yyvsp[0].attrib));
 }
-#line 1629 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1617 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 55: /* attr: attrval TOK_EQUAL string  */
@@ -1633,7 +1621,7 @@ yyreduce:
 {
     (yyval.attrib) = MscAllocAttrib((yyvsp[-2].attribType), (yyvsp[0].string));
 }
-#line 1637 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1625 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 67: /* string: TOK_QSTRING  */
@@ -1641,7 +1629,7 @@ yyreduce:
 {
     (yyval.string) = removeEscapes((yyvsp[0].string));
 }
-#line 1645 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1633 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
   case 68: /* string: TOK_STRING  */
@@ -1649,11 +1637,11 @@ yyreduce:
 {
     (yyval.string) = (yyvsp[0].string);
 }
-#line 1653 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1641 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
     break;
 
 
-#line 1657 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-1.x86_64/build/generated_src/mscgen_language.cpp"
+#line 1645 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
 
       default: break;
     }
@@ -1735,6 +1723,7 @@ yyerrorlab:
      label yyerrorlab therefore never appears in user code.  */
   if (0)
     YYERROR;
+  ++yynerrs;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1795,7 +1784,7 @@ yyerrlab1:
 `-------------------------------------*/
 yyacceptlab:
   yyresult = 0;
-  goto yyreturn;
+  goto yyreturnlab;
 
 
 /*-----------------------------------.
@@ -1803,24 +1792,22 @@ yyacceptlab:
 `-----------------------------------*/
 yyabortlab:
   yyresult = 1;
-  goto yyreturn;
+  goto yyreturnlab;
 
 
-#if !defined yyoverflow
-/*-------------------------------------------------.
-| yyexhaustedlab -- memory exhaustion comes here.  |
-`-------------------------------------------------*/
+/*-----------------------------------------------------------.
+| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
+`-----------------------------------------------------------*/
 yyexhaustedlab:
   yyerror (YYPARSE_PARAM, YY_("memory exhausted"));
   yyresult = 2;
-  goto yyreturn;
-#endif
+  goto yyreturnlab;
 
 
-/*-------------------------------------------------------.
-| yyreturn -- parsing is finished, clean up and return.  |
-`-------------------------------------------------------*/
-yyreturn:
+/*----------------------------------------------------------.
+| yyreturnlab -- parsing is finished, clean up and return.  |
+`----------------------------------------------------------*/
+yyreturnlab:
   if (yychar != YYEMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
